==> OpenJDK13U-jdk_x64_mac_openj9_macosXL_13.0.2_8_openj9-0.18.0.tar.gz: jdk.attach/module-info.java <==
/*
 * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
/*
 * ===========================================================================
 * (c) Copyright IBM Corp. 2018, 2018 All Rights Reserved
 * ===========================================================================
 */

/**
 * Defines the attach API.
 *
 * @uses com.sun.tools.attach.spi.AttachProvider
 *
 * @moduleGraph
 * @since 9
 */
module jdk.attach {
    // source file: file:///Users/jenkins/workspace/build-scripts/jobs/jdk13u/jdk13u-mac-x64-openj9-macosXL/workspace/build/src/src/jdk.attach/share/classes/module-info.java
    //              file:///Users/jenkins/workspace/build-scripts/jobs/jdk13u/jdk13u-mac-x64-openj9-macosXL/workspace/build/src/build/macosx-x86_64-server-release/support/j9jcl_sources/jdk.attach/share/classes/module-info.java.extra
    requires jdk.internal.jvmstat;
    exports com.sun.tools.attach;
    exports com.sun.tools.attach.spi;
    exports com.ibm.tools.attach.attacher to jdk.jcmd;
    exports sun.tools.attach to jdk.jcmd;

    uses com.sun.tools.attach.spi.AttachProvider;
    provides com.sun.tools.attach.spi.AttachProvider with com.ibm.tools.attach.attacher.OpenJ9AttachProvider;
}

==> OpenJDK13U-jdk_x64_mac_openj9_macosXL_13_33_openj9-0.16.0.tar.gz: jdk.attach/module-info.java <==
/*
 * Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
/*
 * ===========================================================================
 * (c) Copyright IBM Corp. 2018, 2018 All Rights Reserved
 * ===========================================================================
 */

/**
 * Defines the attach API.
 *
 * @uses com.sun.tools.attach.spi.AttachProvider
 *
 * @moduleGraph
 * @since 9
 */
module jdk.attach {
    // source file: file:///Users/jenkins/workspace/build-scripts/jobs/jdk13u/jdk13u-mac-x64-openj9-macosXL@2/workspace/build/src/src/jdk.attach/share/classes/module-info.java
    //              file:///Users/jenkins/workspace/build-scripts/jobs/jdk13u/jdk13u-mac-x64-openj9-macosXL@2/workspace/build/src/build/macosx-x86_64-server-release/support/j9jcl_sources/jdk.attach/share/classes/module-info.java.extra
    requires jdk.internal.jvmstat;
    exports com.sun.tools.attach;
    exports com.sun.tools.attach.spi;
    exports com.ibm.tools.attach.attacher to jdk.jcmd;
    exports sun.tools.attach to jdk.jcmd;

    uses com.sun.tools.attach.spi.AttachProvider;
    provides com.sun.tools.attach.spi.AttachProvider with com.ibm.tools.attach.attacher.OpenJ9AttachProvider;
}
